Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1021)

Unified Diff: content/browser/media/capture/web_contents_tracker.h

Issue 1112333002: [content/browser/media] Replace MessageLoopProxy usage with ThreadTaskRunnerHandle (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed build break Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/media/capture/web_contents_tracker.h
diff --git a/content/browser/media/capture/web_contents_tracker.h b/content/browser/media/capture/web_contents_tracker.h
index f124eaa47e87e501f25c803606d83b22112b656b..613c971d44531c1d47aa3d7c125357e59cea21d7 100644
--- a/content/browser/media/capture/web_contents_tracker.h
+++ b/content/browser/media/capture/web_contents_tracker.h
@@ -22,7 +22,7 @@
#include "content/public/browser/web_contents_observer.h"
namespace base {
-class MessageLoopProxy;
+class SingleThreadTaskRunner;
}
namespace content {
@@ -99,8 +99,8 @@ class CONTENT_EXPORT WebContentsTracker
// RenderWidgetHosts.
const bool track_fullscreen_rwh_;
- // MessageLoop corresponding to the thread that called Start().
- scoped_refptr<base::MessageLoopProxy> message_loop_;
+ // TaskRunner corresponding to the thread that called Start().
+ scoped_refptr<base::SingleThreadTaskRunner> task_runner_;
// Callback to run when the target RenderWidgetHost has changed.
ChangeCallback callback_;

Powered by Google App Engine
This is Rietveld 408576698